@@ -1,6 +1,6 @@
 /*
     orzcharlist
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -350,10 +350,10 @@ orz_charlist_init (OrzCharlist *charlist)
   g_signal_connect (G_OBJECT (charlist), "delete-event",
                                     G_CALLBACK (orz_charlist_delete), NULL);
   /* ja:ボタン */
-  charlist->ok_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
-                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
   charlist->cancel_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+  charlist->ok_button = gtk_dialog_add_button (GTK_DIALOG (charlist),
+                                        GTK_STOCK_OK, GTK_RESPONSE_OK);
   /* ja:リストボックス */
   charlist->store = gtk_list_store_new (1, G_TYPE_STRING);
   charlist->tview = gtk_tree_view_new_with_model
@@ -386,8 +386,8 @@ orz_charlist_init (OrzCharlist *charlist)
   g_signal_connect (G_OBJECT (charlist->charset), "edited",
                                 G_CALLBACK (orz_charlist_edited), charlist);
   /* ja:ボタン */
-  charlist->new_button = gtk_button_new_from_stock (GTK_STOCK_NEW);
-  charlist->remove_button = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  charlist->new_button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+  charlist->remove_button = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   charlist->up_button = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
   charlist->down_button = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
   g_signal_connect (G_OBJECT (charlist->new_button), "clicked",
