@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "orzcharset.h"
 #include <gdk/gdkkeysyms.h>
@@ -52,7 +52,7 @@ orz_charset_get_type (void)
 
   if (!orz_charset_type)
     {
-      static const GTypeInfo charset_info =
+      const static GTypeInfo charset_info =
       {
         sizeof (OrzCharsetClass),
         NULL,               /* base_init */
@@ -154,10 +154,10 @@ orz_charset_init (OrzCharset *charset)
   gtk_combo_box_set_model (GTK_COMBO_BOX (charset),
                                             GTK_TREE_MODEL (charset->store));
   gtk_combo_box_entry_set_text_column (GTK_COMBO_BOX_ENTRY (charset), 0);
-  g_signal_connect (G_OBJECT (GTK_BIN (charset)->child), "activate",
-                                G_CALLBACK (orz_charset_activate), charset);
-  g_signal_connect (G_OBJECT (GTK_BIN (charset)->child), "changed",
-                                G_CALLBACK (orz_charset_changed), charset);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (charset))),
+                    "activate", G_CALLBACK (orz_charset_activate), charset);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (charset))),
+                    "changed", G_CALLBACK (orz_charset_changed), charset);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_combo_set_value_in_list (GTK_COMBO (charset), FALSE, FALSE);
   gtk_combo_set_case_sensitive (GTK_COMBO (charset), TRUE);
@@ -195,7 +195,7 @@ orz_charset_get_charset (OrzCharset *charset)
 {
 #if GTK_CHECK_VERSION(2,4,0)
   return charset ? g_strdup (gtk_entry_get_text
-                            (GTK_ENTRY (GTK_BIN (charset)->child))) : NULL;
+                (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (charset))))) : NULL;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   return charset ? g_strdup (gtk_entry_get_text
                             (GTK_ENTRY (GTK_COMBO (charset)->entry))) : NULL;
@@ -214,7 +214,8 @@ orz_charset_set_charset (OrzCharset *charset,
   if (!charset)
     return FALSE;
 #if GTK_CHECK_VERSION(2,4,0)
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (charset)->child), str ? str : "");
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (charset))),
+                                                            str ? str : "");
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (charset)->entry), str ? str : "");
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -283,7 +284,7 @@ orz_charset_add_candidate (OrzCharset *charset,
 
   if (!charset || !candidate)
     return FALSE;
-  str = g_strsplit (candidate, ",", G_MAXINT);
+  str = g_strsplit (candidate, ",", 0);
   for (i = 0; str[i]; i++)
     if (charuty_is_valid (str[i]))
       {
@@ -368,7 +369,7 @@ orz_charset_remove_candidate (OrzCharset *charset,
     return FALSE;
   if (candidate)
     {
-      str = g_strsplit (candidate, ",", G_MAXINT);
+      str = g_strsplit (candidate, ",", 0);
       for (i = 0; str[i]; i++)
         {
           gint j;
@@ -433,7 +434,7 @@ orz_charset_is_valid (OrzCharset *charset)
 {
 #if GTK_CHECK_VERSION(2,4,0)
   return charset ? charuty_is_valid (gtk_entry_get_text
-                            (GTK_ENTRY (GTK_BIN (charset)->child))) : FALSE;
+                (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (charset))))) : FALSE;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   return charset ? charuty_is_valid (gtk_entry_get_text
                             (GTK_ENTRY (GTK_COMBO (charset)->entry))) : FALSE;
