@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "add.h"
 #include "general.h"
 #include "mm_list.h"
@@ -49,8 +48,8 @@ add_dialog_clicked (GtkWidget *widget,
 #if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_file_chooser_dialog_new (_("Browse"),
                     GTK_WINDOW (adddlg->dialog), GTK_FILE_CHOOSER_ACTION_OPEN,
-                    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                     NULL);
   file = g_filename_from_utf8 (gtk_entry_get_text (GTK_ENTRY (adddlg->entry)),
                                                         -1, NULL, NULL, NULL);
@@ -139,26 +138,16 @@ add_dialog_changed (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-add_dialog_key_press (GtkWidget    *widget,
-                       GdkEventKey *event,
-                       gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:追加ダイアログ表示
     mmaid,ウインドウ情報                                                    */
 void
 add_dialog (MmaidWindow *mmaid)
 {
+  gchar *title;
   gint i, n, c, count;
   GList *glist_title = NULL, *glist_artist = NULL, *glist_album = NULL;
   GList *glist_comment = NULL, *glist_genre = NULL;
+  GtkStockItem stock_item;
   GtkWidget *table, *hbox, *button, *check, *entry, *spin;
   GtkWidget *combo_title, *combo_artist, *combo_album;
   GtkWidget *combo_comment, *combo_genre;
@@ -169,15 +158,18 @@ add_dialog (MmaidWindow *mmaid)
 
   adddlg.list = mmaid->list;
   /* ja:メインウインドウ */
+  gtk_stock_lookup (GTK_STOCK_ADD, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
   adddlg.dialog = gtk_dialog_new_with_buttons
-                            (_("Add"),
+                            (title,
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (adddlg.dialog), "key-press-event",
-                                    G_CALLBACK (add_dialog_key_press), NULL);
+  g_free (title);
+  g_signal_connect (G_OBJECT (adddlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ボタン */
   button = gtk_button_new_with_mnemonic (_("_Browse..."));
   g_signal_connect (G_OBJECT (button), "clicked",
@@ -261,36 +253,36 @@ add_dialog (MmaidWindow *mmaid)
   mm_list_get_cursor (MM_LIST (mmaid->list), &n, &c);
   id3tag = n >= 0 ? mm_list_get_nth (MM_LIST (mmaid->list), n) : NULL;
 #if GTK_CHECK_VERSION(2,4,0)
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_title)->child),
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_title))),
                             id3tag && id3tag->title ? id3tag->title : "");
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_artist)->child),
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_artist))),
                             id3tag && id3tag->artist ? id3tag->artist : "");
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_album)->child),
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_album))),
                             id3tag && id3tag->album ? id3tag->album : "");
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_comment)->child),
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_comment))),
                             id3tag && id3tag->comment ? id3tag->comment : "");
-  gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_genre)->child),
+  gtk_entry_set_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_genre))),
                             id3tag && id3tag->genre ? id3tag->genre : "");
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_title)->child), "activate",
-                                    G_CALLBACK (add_dialog_activate), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_artist)->child), "activate",
-                                    G_CALLBACK (add_dialog_activate), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_album)->child), "activate",
-                                    G_CALLBACK (add_dialog_activate), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_comment)->child), "activate",
-                                    G_CALLBACK (add_dialog_activate), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_genre)->child), "activate",
-                                    G_CALLBACK (add_dialog_activate), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_title)->child), "changed",
-                                    G_CALLBACK (add_dialog_changed), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_artist)->child), "changed",
-                                    G_CALLBACK (add_dialog_changed), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_album)->child), "changed",
-                                    G_CALLBACK (add_dialog_changed), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_comment)->child), "changed",
-                                    G_CALLBACK (add_dialog_changed), &adddlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_genre)->child), "changed",
-                                    G_CALLBACK (add_dialog_changed), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_title))),
+                        "activate", G_CALLBACK (add_dialog_activate), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_artist))),
+                        "activate", G_CALLBACK (add_dialog_activate), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_album))),
+                        "activate", G_CALLBACK (add_dialog_activate), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_comment))),
+                        "activate", G_CALLBACK (add_dialog_activate), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_genre))),
+                        "activate", G_CALLBACK (add_dialog_activate), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_title))),
+                        "changed", G_CALLBACK (add_dialog_changed), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_artist))),
+                        "changed", G_CALLBACK (add_dialog_changed), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_album))),
+                        "changed", G_CALLBACK (add_dialog_changed), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_comment))),
+                        "changed", G_CALLBACK (add_dialog_changed), &adddlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_genre))),
+                        "changed", G_CALLBACK (add_dialog_changed), &adddlg);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo_title)->entry),
                             id3tag && id3tag->title ? id3tag->title : "");
@@ -393,11 +385,11 @@ add_dialog (MmaidWindow *mmaid)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_file), adddlg.entry);
 #if GTK_CHECK_VERSION(2,4,0)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_title),
-                                            GTK_BIN (combo_title)->child);
+                                gtk_bin_get_child (GTK_BIN (combo_title)));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_artist),
-                                            GTK_BIN (combo_artist)->child);
+                                gtk_bin_get_child (GTK_BIN (combo_artist)));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_album),
-                                            GTK_BIN (combo_album)->child);
+                                gtk_bin_get_child (GTK_BIN (combo_album)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_title),
                                             GTK_COMBO (combo_title)->entry);
@@ -409,9 +401,9 @@ add_dialog (MmaidWindow *mmaid)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_year), entry);
 #if GTK_CHECK_VERSION(2,4,0)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_comment),
-                                            GTK_BIN (combo_comment)->child);
+                                gtk_bin_get_child (GTK_BIN (combo_comment)));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_genre),
-                                            GTK_BIN (combo_genre)->child);
+                                gtk_bin_get_child (GTK_BIN (combo_genre)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_comment),
                                             GTK_COMBO (combo_comment)->entry);
@@ -483,11 +475,14 @@ add_dialog (MmaidWindow *mmaid)
         gtk_widget_grab_focus (adddlg.entry); break;
       case MM_LIST_TITLE:
 #if GTK_CHECK_VERSION(2,4,0)
-        gtk_widget_grab_focus (GTK_BIN (combo_title)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_title)));
+        break;
       case MM_LIST_ARTIST:
-        gtk_widget_grab_focus (GTK_BIN (combo_artist)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_artist)));
+        break;
       case MM_LIST_ALBUM:
-        gtk_widget_grab_focus (GTK_BIN (combo_album)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_album)));
+        break;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
         gtk_widget_grab_focus (GTK_COMBO (combo_title)->entry); break;
       case MM_LIST_ARTIST:
@@ -499,11 +494,13 @@ add_dialog (MmaidWindow *mmaid)
         gtk_widget_grab_focus (entry); break;
       case MM_LIST_COMMENT:
 #if GTK_CHECK_VERSION(2,4,0)
-        gtk_widget_grab_focus (GTK_BIN (combo_comment)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_comment)));
+        break;
       case MM_LIST_TRACK:
         gtk_widget_grab_focus (check); break;
       case MM_LIST_GENRE:
-        gtk_widget_grab_focus (GTK_BIN (combo_genre)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_genre)));
+        break;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
         gtk_widget_grab_focus (GTK_COMBO (combo_comment)->entry); break;
       case MM_LIST_TRACK:
@@ -538,11 +535,11 @@ add_dialog (MmaidWindow *mmaid)
           id3tag = g_malloc0 (sizeof (ID3Tag));
 #if GTK_CHECK_VERSION(2,4,0)
           title   = gtk_entry_get_text
-                                (GTK_ENTRY (GTK_BIN (combo_title)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_title))));
           artist  = gtk_entry_get_text
-                                (GTK_ENTRY (GTK_BIN (combo_artist)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_artist))));
           album   = gtk_entry_get_text
-                                (GTK_ENTRY (GTK_BIN (combo_album)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_album))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
           title   = gtk_entry_get_text
                                 (GTK_ENTRY (GTK_COMBO (combo_title)->entry));
@@ -554,7 +551,7 @@ add_dialog (MmaidWindow *mmaid)
           year    = gtk_entry_get_text (GTK_ENTRY (entry));
 #if GTK_CHECK_VERSION(2,4,0)
           comment = gtk_entry_get_text
-                                (GTK_ENTRY (GTK_BIN (combo_comment)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_comment))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
           comment = gtk_entry_get_text
                                 (GTK_ENTRY (GTK_COMBO (combo_comment)->entry));
@@ -564,10 +561,10 @@ add_dialog (MmaidWindow *mmaid)
               ? gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin)) : -1;
 #if GTK_CHECK_VERSION(2,4,0)
           genre   = gtk_entry_get_text
-                                (GTK_ENTRY (GTK_BIN (combo_genre)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_genre))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
           genre   = gtk_entry_get_text
-                                (GTK_ENTRY (GTK_COMBO (combo_genre)->entry));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_COMBO (combo_genre))));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
           charset = orz_charset_get_charset (ORZ_CHARSET (adddlg.charset));
           if (file && file[0] != '\0')
