@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,6 +26,7 @@
 #include "genre.h"
 #include "mm_dialog.h"
 #include "mm_list.h"
+#include "mmaid.h"
 #include "process.h"
 #include "reload.h"
 #include "root.h"
@@ -58,21 +59,24 @@ void
 command_open (GtkWidget *widget,
               gpointer   user_data)
 {
-  gchar *file = NULL, *path;
+  gchar *file = NULL, *path, *title;
+  GtkStockItem stock_item;
   GtkWidget *dialog;
 
+  gtk_stock_lookup (GTK_STOCK_OPEN, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
 #if GTK_CHECK_VERSION(2,4,0)
-  dialog = gtk_file_chooser_dialog_new (_("Open"),
+  dialog = gtk_file_chooser_dialog_new (title,
                         GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_OPEN,
-                        GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                         NULL);
   if (open_path)
     gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), open_path);
   if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
     file = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-  dialog = gtk_file_selection_new (_("Open"));
+  dialog = gtk_file_selection_new (title);
   if (open_path)
     {
       path = g_strconcat (open_path, G_SEARCHPATH_SEPARATOR_S, NULL);
@@ -84,6 +88,7 @@ command_open (GtkWidget *widget,
     file = g_strdup (gtk_file_selection_get_filename
                                                 (GTK_FILE_SELECTION (dialog)));
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
+  g_free (title);
   gtk_widget_destroy (dialog);
   if (file)
     {
@@ -160,6 +165,8 @@ command_save (GtkWidget *widget,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
                     _("%s\nThis file is existed.\n\nOver write?"), utf8str);
           g_free (utf8str);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
           gtk_widget_destroy (dialog);
         }
@@ -247,10 +254,11 @@ void
 command_saveas (GtkWidget *widget,
                 gpointer   user_data)
 {
-  gchar *file, *root = NULL, *charset, *name, *path, *tmp, **ary;
+  gchar *file, *root = NULL, *charset, *name, *path, *tmp, **ary, *title;
   gint playlist, i, page_num;
   guint filekind;
   GList *glist = NULL;
+  GtkStockItem stock_item;
   GtkWidget *dialog, *hbox0, *hbox1, *vbox;
   GtkWidget *combo0, *combo1, *label0, *label1;
   GtkWidget *radio0, *radio1, *radio2, *radio3, *radio4;
@@ -285,6 +293,8 @@ command_saveas (GtkWidget *widget,
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
                             GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
                             _("Root Directory Error"));
+      g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
       return;
@@ -326,15 +336,18 @@ command_saveas (GtkWidget *widget,
   if (!root)
     root = g_filename_from_utf8 (path, -1, NULL, NULL, NULL);
   /* ja:ダイアログ */
+  gtk_stock_lookup (GTK_STOCK_SAVE_AS, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
 #if GTK_CHECK_VERSION(2,4,0)
-  dialog = gtk_file_chooser_dialog_new (_("Save As"),
+  dialog = gtk_file_chooser_dialog_new (title,
                         GTK_WINDOW (window), GTK_FILE_CHOOSER_ACTION_SAVE,
-                        GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        GTK_STOCK_SAVE_AS, GTK_RESPONSE_ACCEPT,
                         NULL);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-  dialog = gtk_file_selection_new (_("Save As"));
+  dialog = gtk_file_selection_new (title);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
+  g_free (title);
   /* ja:ラジオボタン */
   radio0 = gtk_radio_button_new_with_mnemonic (NULL, _("_iDB File"));
   radio1 = gtk_radio_button_new_with_mnemonic_from_widget
@@ -512,6 +525,8 @@ command_saveas (GtkWidget *widget,
                     GTK_MESSAGE_INFO, GTK_BUTTONS_YES_NO,
                     _("%s\nThis file is existed.\n\nOver write?"), utf8str);
           g_free (utf8str);
+          g_signal_connect (G_OBJECT (dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
           result = gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_YES;
           gtk_widget_destroy (dialog);
         }
@@ -826,7 +841,9 @@ command_refresh (GtkWidget *widget,
                  gpointer   user_data)
 {
   gboolean selected = FALSE;
+  gchar *title;
   gint i, count;
+  GtkStockItem stock_item;
   GtkWidget *dialog;
   MmaidWindow *mmaid;
 
@@ -841,7 +858,10 @@ command_refresh (GtkWidget *widget,
       }
   userbreak = TRUE;
   dialog = mm_dialog_new ();
-  gtk_window_set_title (GTK_WINDOW (dialog), _("Refresh"));
+  gtk_stock_lookup (GTK_STOCK_REFRESH, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
+  gtk_window_set_title (GTK_WINDOW (dialog), title);
+  g_free (title);
   mm_list_set_editable (MM_LIST (MM_DIALOG (dialog)->list), TRUE);
   g_signal_connect (G_OBJECT (MM_DIALOG (dialog)->abort_button),
                         "clicked", G_CALLBACK (command_dialog_abort), dialog);
@@ -1069,8 +1089,8 @@ command_search (GtkWidget *widget,
   dialog = gtk_file_chooser_dialog_new (_("Browse"),
                         GTK_WINDOW (window),
                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
-                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                        GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
                         NULL);
   if (path)
     {
