@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "edit.h"
 #include "general.h"
 #include "mm_list.h"
@@ -48,8 +47,8 @@ edit_dialog_clicked (GtkWidget  *widget,
 #if GTK_CHECK_VERSION(2,4,0)
   dialog = gtk_file_chooser_dialog_new (_("Browse"),
                     GTK_WINDOW (editdlg->dialog), GTK_FILE_CHOOSER_ACTION_OPEN,
-                    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                     GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                    GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
                     NULL);
   file = g_filename_from_utf8 (gtk_entry_get_text (GTK_ENTRY (editdlg->entry)),
                                                         -1, NULL, NULL, NULL);
@@ -162,18 +161,6 @@ edit_dialog_changed (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-edit_dialog_key_press (GtkWidget   *widget,
-                       GdkEventKey *event,
-                       gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:編集ダイアログ表示
     mmaid,ウインドウ情報                                                    */
 void
@@ -189,18 +176,35 @@ edit_dialog (MmaidWindow *mmaid)
   GtkWidget *label_comment, *label_year, *label_genre, *label_charset;
   const ID3Tag *id3tag = NULL;
   EditDialog editdlg;
+#if GTK_CHECK_VERSION(2,6,0)
+  gchar *title;
+  GtkStockItem stock_item;
+#endif /* GTK_CHECK_VERSION(2,6,0) */
 
   editdlg.list = mmaid->list;
   /* ja:メインウインドウ */
+#if GTK_CHECK_VERSION(2,6,0)
+  gtk_stock_lookup (GTK_STOCK_EDIT, &stock_item);
+  title = misc_mnemonic_to_text (stock_item.label);
+  editdlg.dialog = gtk_dialog_new_with_buttons
+                            (title,
+                            GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
+                            NULL);
+  g_free (title);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
   editdlg.dialog = gtk_dialog_new_with_buttons
                             (_("Edit"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT (editdlg.dialog), "key-press-event",
-                                    G_CALLBACK (edit_dialog_key_press), NULL);
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+  g_signal_connect (G_OBJECT (editdlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ラベル */
   label_title = gtk_label_new_with_mnemonic (_("_Title"));
   label_artist = gtk_label_new_with_mnemonic (_("_Artist"));
@@ -324,15 +328,20 @@ edit_dialog (MmaidWindow *mmaid)
   if (s == 1)
     {
 #if GTK_CHECK_VERSION(2,4,0)
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_title)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_title))),
                                     id3tag->title ? id3tag->title : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_artist)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_artist))),
                                     id3tag->artist ? id3tag->artist : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_album)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_album))),
                                     id3tag->album ? id3tag->album : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_comment)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_comment))),
                                     id3tag->comment ? id3tag->comment : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_genre)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_genre))),
                                     id3tag->genre ? id3tag->genre : "");
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo_title)->entry),
@@ -373,15 +382,20 @@ edit_dialog (MmaidWindow *mmaid)
                         && g_strcmp (id3tag->charset, id3tag0->charset) == 0;
           }
 #if GTK_CHECK_VERSION(2,4,0)
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_title)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_title))),
                                                     t ? id3tag->title   : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_artist)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_artist))),
                                                     a ? id3tag->artist  : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_album)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_album))),
                                                     l ? id3tag->album   : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_comment)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_comment))),
                                                     c ? id3tag->comment : "");
-      gtk_entry_set_text (GTK_ENTRY (GTK_BIN (combo_genre)->child),
+      gtk_entry_set_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_genre))),
                                                     g ? id3tag->genre   : "");
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (combo_title)->entry),
@@ -399,16 +413,16 @@ edit_dialog (MmaidWindow *mmaid)
                                                     e ? id3tag->charset : "");
     }
 #if GTK_CHECK_VERSION(2,4,0)
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_title)->child), "activate",
-                                G_CALLBACK (edit_dialog_activate), &editdlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_artist)->child), "activate",
-                                G_CALLBACK (edit_dialog_activate), &editdlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_album)->child), "activate",
-                                G_CALLBACK (edit_dialog_activate), &editdlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_comment)->child), "activate",
-                                G_CALLBACK (edit_dialog_activate), &editdlg);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_genre)->child), "activate",
-                                G_CALLBACK (edit_dialog_activate), &editdlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_title))),
+                    "activate", G_CALLBACK (edit_dialog_activate), &editdlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_artist))),
+                    "activate", G_CALLBACK (edit_dialog_activate), &editdlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_album))),
+                    "activate", G_CALLBACK (edit_dialog_activate), &editdlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_comment))),
+                    "activate", G_CALLBACK (edit_dialog_activate), &editdlg);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_genre))),
+                    "activate", G_CALLBACK (edit_dialog_activate), &editdlg);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   g_signal_connect (G_OBJECT (GTK_COMBO (combo_title)->entry), "activate",
                                 G_CALLBACK (edit_dialog_activate), &editdlg);
@@ -424,16 +438,16 @@ edit_dialog (MmaidWindow *mmaid)
   g_signal_connect (G_OBJECT (editdlg.charset), "activate",
                                 G_CALLBACK (edit_dialog_activate), &editdlg);
 #if GTK_CHECK_VERSION(2,4,0)
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_title)->child), "changed",
-                            G_CALLBACK (edit_dialog_changed), label_title);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_artist)->child), "changed",
-                            G_CALLBACK (edit_dialog_changed), label_artist);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_album)->child), "changed",
-                            G_CALLBACK (edit_dialog_changed), label_album);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_comment)->child), "changed",
-                            G_CALLBACK (edit_dialog_changed), label_comment);
-  g_signal_connect (G_OBJECT (GTK_BIN (combo_genre)->child), "changed",
-                            G_CALLBACK (edit_dialog_changed), label_genre);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_title))),
+                    "changed", G_CALLBACK (edit_dialog_changed), label_title);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_artist))),
+                    "changed", G_CALLBACK (edit_dialog_changed), label_artist);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_album))),
+                    "changed", G_CALLBACK (edit_dialog_changed), label_album);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_comment))),
+                    "changed", G_CALLBACK (edit_dialog_changed), label_comment);
+  g_signal_connect (G_OBJECT (gtk_bin_get_child (GTK_BIN (combo_genre))),
+                    "changed", G_CALLBACK (edit_dialog_changed), label_genre);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   g_signal_connect (G_OBJECT (GTK_COMBO (combo_title)->entry), "changed",
                             G_CALLBACK (edit_dialog_changed), label_title);
@@ -476,12 +490,12 @@ edit_dialog (MmaidWindow *mmaid)
         G_CALLBACK (edit_dialog_changed), gtk_bin_get_child (GTK_BIN (check)));
   /* ja:ラベル */
 #if GTK_CHECK_VERSION(2,4,0)
-  gtk_label_set_mnemonic_widget (GTK_LABEL(label_title),
-                                            GTK_BIN (combo_title)->child);
-  gtk_label_set_mnemonic_widget (GTK_LABEL(label_artist),
-                                            GTK_BIN (combo_artist)->child);
-  gtk_label_set_mnemonic_widget (GTK_LABEL(label_album),
-                                            GTK_BIN (combo_album)->child);
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label_title),
+                                gtk_bin_get_child (GTK_BIN (combo_title)));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label_artist),
+                                gtk_bin_get_child (GTK_BIN (combo_artist)));
+  gtk_label_set_mnemonic_widget (GTK_LABEL (label_album),
+                                gtk_bin_get_child (GTK_BIN (combo_album)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_title),
                                             GTK_COMBO (combo_title)->entry);
@@ -493,9 +507,9 @@ edit_dialog (MmaidWindow *mmaid)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_year), entry);
 #if GTK_CHECK_VERSION(2,4,0)
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_comment),
-                                            GTK_BIN (combo_comment)->child);
+                                gtk_bin_get_child (GTK_BIN (combo_comment)));
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_genre),
-                                            GTK_BIN (combo_genre)->child);
+                                gtk_bin_get_child (GTK_BIN (combo_genre)));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
   gtk_label_set_mnemonic_widget (GTK_LABEL (label_comment),
                                             GTK_COMBO (combo_comment)->entry);
@@ -606,11 +620,14 @@ edit_dialog (MmaidWindow *mmaid)
         break;
       case MM_LIST_TITLE:
 #if GTK_CHECK_VERSION(2,4,0)
-        gtk_widget_grab_focus (GTK_BIN (combo_title)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_title)));
+        break;
       case MM_LIST_ARTIST:
-        gtk_widget_grab_focus (GTK_BIN (combo_artist)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_artist)));
+        break;
       case MM_LIST_ALBUM:
-        gtk_widget_grab_focus (GTK_BIN (combo_album)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_album)));
+        break;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
         gtk_widget_grab_focus (GTK_COMBO (combo_title)->entry); break;
       case MM_LIST_ARTIST:
@@ -622,7 +639,8 @@ edit_dialog (MmaidWindow *mmaid)
         gtk_widget_grab_focus (entry); break;
       case MM_LIST_COMMENT:
 #if GTK_CHECK_VERSION(2,4,0)
-        gtk_widget_grab_focus (GTK_BIN (combo_comment)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_comment)));
+        break;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
         gtk_widget_grab_focus (GTK_COMBO (combo_comment)->entry); break;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -630,7 +648,8 @@ edit_dialog (MmaidWindow *mmaid)
         gtk_widget_grab_focus (check); break;
       case MM_LIST_GENRE:
 #if GTK_CHECK_VERSION(2,4,0)
-        gtk_widget_grab_focus (GTK_BIN (combo_genre)->child); break;
+        gtk_widget_grab_focus (gtk_bin_get_child (GTK_BIN (combo_genre)));
+        break;
 #else /* not GTK_CHECK_VERSION(2,4,0) */
         gtk_widget_grab_focus (GTK_COMBO (combo_genre)->entry); break;
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
@@ -665,9 +684,12 @@ edit_dialog (MmaidWindow *mmaid)
           f = FALSE;
         }
 #if GTK_CHECK_VERSION(2,4,0)
-      title   = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo_title)->child));
-      artist  = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo_artist)->child));
-      album   = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo_album)->child));
+      title   = gtk_entry_get_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_title))));
+      artist  = gtk_entry_get_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_artist))));
+      album   = gtk_entry_get_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_album))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       title   = gtk_entry_get_text
                                 (GTK_ENTRY (GTK_COMBO (combo_title)->entry));
@@ -679,7 +701,7 @@ edit_dialog (MmaidWindow *mmaid)
       year    = gtk_entry_get_text (GTK_ENTRY (entry));
 #if GTK_CHECK_VERSION(2,4,0)
       comment = gtk_entry_get_text
-                                (GTK_ENTRY (GTK_BIN (combo_comment)->child));
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_comment))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       comment = gtk_entry_get_text
                                 (GTK_ENTRY (GTK_COMBO (combo_comment)->entry));
@@ -687,7 +709,8 @@ edit_dialog (MmaidWindow *mmaid)
       track   = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (check))
               ? gtk_spin_button_get_value_as_int (GTK_SPIN_BUTTON (spin)) : -1;
 #if GTK_CHECK_VERSION(2,4,0)
-      genre   = gtk_entry_get_text (GTK_ENTRY (GTK_BIN (combo_genre)->child));
+      genre   = gtk_entry_get_text
+                    (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (combo_genre))));
 #else /* not GTK_CHECK_VERSION(2,4,0) */
       genre   = gtk_entry_get_text
                                 (GTK_ENTRY (GTK_COMBO (combo_genre)->entry));
