@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "genre.h"
 
 
@@ -317,18 +316,6 @@ void genre_dialog_cursor_changed (GtkTreeView *tview,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-genre_dialog_key_press (GtkWidget   *widget,
-                        GdkEventKey *event,
-                        gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:ジャンルダイアログ表示                                               */
 void
 genre_dialog (void)
@@ -344,16 +331,16 @@ genre_dialog (void)
                             (_("Genre"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
   gtk_window_set_default_size (GTK_WINDOW (gnrdlg.dialog),
                     gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
-  g_signal_connect_after (G_OBJECT (gnrdlg.dialog), "key-press-event",
-                                    G_CALLBACK (genre_dialog_key_press), NULL);
+  g_signal_connect (G_OBJECT (gnrdlg.dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ボタン */
-  gnrdlg.button0 = gtk_button_new_from_stock (GTK_STOCK_NEW);
-  gnrdlg.button1 = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  gnrdlg.button0 = gtk_button_new_from_stock (GTK_STOCK_ADD);
+  gnrdlg.button1 = gtk_button_new_from_stock (GTK_STOCK_REMOVE);
   gnrdlg.button2 = gtk_button_new_from_stock (GTK_STOCK_GO_UP);
   gnrdlg.button3 = gtk_button_new_from_stock (GTK_STOCK_GO_DOWN);
   g_signal_connect (G_OBJECT (gnrdlg.button0), "clicked",
