@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,9 +22,9 @@
 #include "file.h"
 #include "general.h"
 #include "genre.h"
+#include "icons.h"
 #include "mm_list.h"
 #include "sigmain.h"
-#include "toolbar.h"
 #include "misc/argument.h"
 #include "misc/charuty.h"
 #include "misc/fileio.h"
@@ -60,66 +60,104 @@ GdkAtom atom_id3tag;                /* ja:ID3タグ */
 GtkWidget *window;                  /* ja:ウインドウ */
 GtkWidget *mdi;                     /* en:MDI */
 GtkPositionType n_pos = GTK_POS_TOP;/* ja:ノートブックの位置 */
-GtkTargetEntry targets_mmaid[] = {  /* ja:提供可能なセレクション */
-    {"Melody maid ID3 Tag", 0, TARGET_MMAID}};
 #ifdef G_OS_WIN32
 UINT uFormat = 0;                   /* ja:クリップボード */
 #endif /* G_OS_WIN32 */
 MiscCreateMenuEntry menu_entries[] = {
-{"/",                     NULL,                         NULL,              MISC_CREATE_MENU_BAR,       NULL,            NULL, NULL},
-{"/file",                 N_("_File"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
-{"/file/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
-{"/file/new",             N_("_New"),                   "<control>N",      MISC_CREATE_MENU_ITEM,      command_new,     NULL, NULL},
-{"/file/open",            N_("_Open..."),               "<control>O",      MISC_CREATE_MENU_ITEM,      command_open,    NULL, NULL},
-{"/file/close",           N_("_Close"),                 "<control>W",      MISC_CREATE_MENU_ITEM,      command_close,   NULL, NULL},
-{"/file/save",            N_("_Save"),                  "<control>S",      MISC_CREATE_MENU_ITEM,      command_save,    NULL, NULL},
-{"/file/saveas",          N_("Save _As..."),            NULL,              MISC_CREATE_MENU_ITEM,      command_saveas,  NULL, NULL},
-{"/file/reload",          N_("_Reload..."),             "<control>R",      MISC_CREATE_MENU_ITEM,      command_reload,  NULL, NULL},
-{"/file/sep1",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
-{"/file/export",          N_("_Export..."),             "<control>E",      MISC_CREATE_MENU_ITEM,      command_export,  NULL, NULL},
-{"/file/sep2",            NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
-{"/file/exit",            N_("E_xit"),                  "<control>Q",      MISC_CREATE_MENU_ITEM,      command_exit,    NULL, NULL},
-{"/tag",                  N_("_Tag"),                   NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
-{"/tag/",                 NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
-{"/tag/up",               N_("_Up"),                    NULL,              MISC_CREATE_MENU_ITEM,      command_up,      NULL, NULL},
-{"/tag/down",             N_("_Down"),                  NULL,              MISC_CREATE_MENU_ITEM,      command_down,    NULL, NULL},
-{"/tag/sep1",             NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
-{"/tag/root",             N_("R_oot..."),               "<control>H",      MISC_CREATE_MENU_ITEM,      command_root,    NULL, NULL},
-{"/tag/refresh",          N_("_Refresh..."),            "F5",              MISC_CREATE_MENU_ITEM,      command_refresh, NULL, NULL},
-{"/tag/add",              N_("A_dd..."),                "Insert",          MISC_CREATE_MENU_ITEM,      command_add,     NULL, NULL},
-{"/tag/edit",             N_("_Edit..."),               "<control>Return", MISC_CREATE_MENU_ITEM,      command_edit,    NULL, NULL},
-{"/tag/search",           N_("_Search..."),             "<control>F",      MISC_CREATE_MENU_ITEM,      command_search,  NULL, NULL},
-{"/tag/sep2",             NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
-{"/tag/cut",              N_("Cu_t"),                   "<control>X",      MISC_CREATE_MENU_ITEM,      command_cut,     NULL, NULL},
-{"/tag/copy",             N_("_Copy"),                  "<control>C",      MISC_CREATE_MENU_ITEM,      command_copy,    NULL, NULL},
-{"/tag/paste",            N_("_Paste"),                 "<control>V",      MISC_CREATE_MENU_ITEM,      command_paste,   NULL, NULL},
-{"/tag/delete",           N_("De_lete"),                "Delete",          MISC_CREATE_MENU_ITEM,      command_delete,  NULL, NULL},
-{"/tag/sep3",             NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
-{"/tag/all",              N_("_All"),                   "<control>A",      MISC_CREATE_MENU_ITEM,      command_all,     NULL, NULL},
-{"/option",               N_("_Option"),                NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
-{"/option/",              NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
-{"/option/configuration", N_("_Configuration..."),      NULL,              MISC_CREATE_MENU_ITEM,      command_conf,    NULL, NULL},
-{"/option/genre",         N_("_Genre..."),              NULL,              MISC_CREATE_MENU_ITEM,      command_genre,   NULL, NULL},
-{"/option/character",     N_("Character _Encoding..."), NULL,              MISC_CREATE_MENU_ITEM,      command_charset, NULL, NULL},
-{"/option/process",       N_("_Process..."),            NULL,              MISC_CREATE_MENU_ITEM,      command_process, NULL, NULL},
-{"/window",               N_("_Window"),                NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
-{"/window/",              NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
-{"/help",                 N_("_Help"),                  NULL,              MISC_CREATE_MENU_ITEM,      NULL,            NULL, NULL},
-{"/help/",                NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
-{"/help/about",           N_("_About..."),              NULL,              MISC_CREATE_MENU_ITEM,      command_version, NULL, NULL},
-{NULL,                    NULL,                         NULL,              MISC_CREATE_MENU_TERMINAL,  NULL,            NULL, NULL}};
+{"/",                     NULL,                      NULL,              MISC_CREATE_MENU_BAR,                               NULL,            NULL, NULL},
+{"/file",                 N_("_File"),               NULL,              MISC_CREATE_MENU_ITEM,                              NULL,            NULL, NULL},
+{"/file/",                NULL,                      NULL,              MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
+{"/file/new",             GTK_STOCK_NEW,             NULL,              MISC_CREATE_MENU_STOCK,                             command_new,     NULL, NULL},
+{"/file/open",            GTK_STOCK_OPEN,            NULL,              MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_open,    NULL, NULL},
+{"/file/close",           GTK_STOCK_CLOSE,           NULL,              MISC_CREATE_MENU_STOCK,                             command_close,   NULL, NULL},
+{"/file/save",            GTK_STOCK_SAVE,            NULL,              MISC_CREATE_MENU_STOCK,                             command_save,    NULL, NULL},
+{"/file/saveas",          GTK_STOCK_SAVE_AS,         NULL,              MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_saveas,  NULL, NULL},
+{"/file/reload",          GTK_STOCK_REVERT_TO_SAVED, "<control>R",      MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_reload,  NULL, NULL},
+{"/file/sep1",            NULL,                      NULL,              MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
+{"/file/export",          N_("_Export"),             "<control>E",      MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_export,  NULL, NULL},
+{"/file/sep2",            NULL,                      NULL,              MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
+{"/file/exit",            GTK_STOCK_QUIT,            NULL,              MISC_CREATE_MENU_STOCK,                             command_exit,    NULL, NULL},
+{"/tag",                  N_("_Tag"),                NULL,              MISC_CREATE_MENU_ITEM,                              NULL,            NULL, NULL},
+{"/tag/",                 NULL,                      NULL,              MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
+{"/tag/up",               GTK_STOCK_GO_UP,           NULL,              MISC_CREATE_MENU_STOCK,                             command_up,      NULL, NULL},
+{"/tag/down",             GTK_STOCK_GO_DOWN,         NULL,              MISC_CREATE_MENU_STOCK,                             command_down,    NULL, NULL},
+{"/tag/sep1",             NULL,                      NULL,              MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
+{"/tag/root",             N_("R_oot"),               "<control>H",      MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_root,    NULL, NULL},
+{"/tag/refresh",          GTK_STOCK_REFRESH,         "F5",              MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_refresh, NULL, NULL},
+{"/tag/add",              GTK_STOCK_ADD,             "Insert",          MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_add,     NULL, NULL},
+#if GTK_CHECK_VERSION(2,6,0)
+{"/tag/edit",             GTK_STOCK_EDIT,            "<control>Return", MISC_CREATE_MENU_STOCK | MISC_CREATE_MENU_ELLIPSIS, command_edit,    NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+{"/tag/edit",             N_("_Edit"),               "<control>Return", MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_edit,    NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+{"/tag/search",           N_("_Search Directory"),   "<control>F",      MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_search,  NULL, NULL},
+{"/tag/sep2",             NULL,                      NULL,              MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
+{"/tag/cut",              GTK_STOCK_CUT,             NULL,              MISC_CREATE_MENU_STOCK,                             command_cut,     NULL, NULL},
+{"/tag/copy",             GTK_STOCK_COPY,            NULL,              MISC_CREATE_MENU_STOCK,                             command_copy,    NULL, NULL},
+{"/tag/paste",            GTK_STOCK_PASTE,           NULL,              MISC_CREATE_MENU_STOCK,                             command_paste,   NULL, NULL},
+{"/tag/delete",           GTK_STOCK_DELETE,          "Delete",          MISC_CREATE_MENU_STOCK,                             command_delete,  NULL, NULL},
+{"/tag/sep3",             NULL,                      NULL,              MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
+#if GTK_CHECK_VERSION(2,10,0)
+{"/tag/all",              GTK_STOCK_SELECT_ALL,      "<control>A",      MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,10,0) */
+{"/tag/all",              N_("_All"),                "<control>A",      MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,10,0) */
+{"/option",               N_("_Option"),             NULL,              MISC_CREATE_MENU_ITEM,                              NULL,            NULL, NULL},
+{"/option/",              NULL,                      NULL,              MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
+{"/option/configuration", GTK_STOCK_PREFERENCES,     NULL,              MISC_CREATE_MENU_STOCK,                             command_conf,    NULL, NULL},
+{"/option/genre",         N_("_Genre"),              NULL,              MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_genre,   NULL, NULL},
+{"/option/character",     N_("Character _Encoding"), NULL,              MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_charset, NULL, NULL},
+{"/option/process",       N_("_Process"),            NULL,              MISC_CREATE_MENU_ITEM | MISC_CREATE_MENU_ELLIPSIS,  command_process, NULL, NULL},
+{"/window",               N_("_Window"),             NULL,              MISC_CREATE_MENU_ITEM,                              NULL,            NULL, NULL},
+{"/window/",              NULL,                      NULL,              MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
+{"/help",                 N_("_Help"),               NULL,              MISC_CREATE_MENU_ITEM,                              NULL,            NULL, NULL},
+{"/help/",                NULL,                      NULL,              MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
+{"/help/about",           N_("_About"),              NULL,              MISC_CREATE_MENU_ITEM,                              command_version, NULL, NULL},
+{NULL,                    NULL,                      NULL,              MISC_CREATE_MENU_TERMINAL,                          NULL,            NULL, NULL}};
 MiscCreateMenuEntry popup_entries[] = {
-{"/",                     NULL,                         NULL,              MISC_CREATE_MENU_SHELL,     NULL,            NULL, NULL},
-{"/play",                 N_("Play"),                   NULL,              MISC_CREATE_MENU_ITEM,      command_play,    NULL, NULL},
-{"/stop",                 N_("Stop"),                   NULL,              MISC_CREATE_MENU_ITEM,      command_stop,    NULL, NULL},
-{"/sep1",                 NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
-{"/cut",                  N_("Cu_t"),                   "<control>X",      MISC_CREATE_MENU_ITEM,      command_cut,     NULL, NULL},
-{"/copy",                 N_("_Copy"),                  "<control>C",      MISC_CREATE_MENU_ITEM,      command_copy,    NULL, NULL},
-{"/paste",                N_("_Paste"),                 "<control>V",      MISC_CREATE_MENU_ITEM,      command_paste,   NULL, NULL},
-{"/delete",               N_("De_lete"),                "Delete",          MISC_CREATE_MENU_ITEM,      command_delete,  NULL, NULL},
-{"/sep2",                 NULL,                         NULL,              MISC_CREATE_MENU_SEPARATOR, NULL,            NULL, NULL},
-{"/all",                  N_("_All"),                   "<control>A",      MISC_CREATE_MENU_ITEM,      command_all,     NULL, NULL},
-{NULL,                    NULL,                         NULL,              MISC_CREATE_MENU_TERMINAL,  NULL,            NULL, NULL}};
+{"/",                     NULL,                      NULL,              MISC_CREATE_MENU_SHELL,                             NULL,            NULL, NULL},
+#if GTK_CHECK_VERSION(2,6,0)
+{"/play",                 GTK_STOCK_MEDIA_PLAY,      NULL,              MISC_CREATE_MENU_STOCK,                             command_play,    NULL, NULL},
+{"/stop",                 GTK_STOCK_MEDIA_STOP,      NULL,              MISC_CREATE_MENU_STOCK,                             command_stop,    NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+{"/play",                 N_("Play"),                NULL,              MISC_CREATE_MENU_ITEM,                              command_play,    NULL, NULL},
+{"/stop",                 N_("Stop"),                NULL,              MISC_CREATE_MENU_ITEM,                              command_stop,    NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+{"/sep1",                 NULL,                      NULL,              MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
+{"/cut",                  GTK_STOCK_CUT,             NULL,              MISC_CREATE_MENU_STOCK,                             command_cut,     NULL, NULL},
+{"/copy",                 GTK_STOCK_COPY,            NULL,              MISC_CREATE_MENU_STOCK,                             command_copy,    NULL, NULL},
+{"/paste",                GTK_STOCK_PASTE,           NULL,              MISC_CREATE_MENU_STOCK,                             command_paste,   NULL, NULL},
+{"/delete",               GTK_STOCK_DELETE,          "Delete",          MISC_CREATE_MENU_STOCK,                             command_delete,  NULL, NULL},
+{"/sep2",                 NULL,                      NULL,              MISC_CREATE_MENU_SEPARATOR,                         NULL,            NULL, NULL},
+#if GTK_CHECK_VERSION(2,10,0)
+{"/all",                  GTK_STOCK_SELECT_ALL,      "<control>A",      MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,10,0) */
+{"/all",                  N_("_All"),                "<control>A",      MISC_CREATE_MENU_ITEM,                              command_all,     NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,10,0) */
+{NULL,                    NULL,                      NULL,              MISC_CREATE_MENU_TERMINAL,                          NULL,            NULL, NULL}};
+MiscCreateToolbarEntry toolbar_entries[] = {
+{"new",     GTK_STOCK_NEW,          NULL,           command_new,     NULL, NULL},
+{"open",    GTK_STOCK_OPEN,         NULL,           command_open,    NULL, NULL},
+{"save",    GTK_STOCK_SAVE,         NULL,           command_save,    NULL, NULL},
+{"sep1",    NULL,                   NULL,           NULL,            NULL, NULL},
+{"cut",     GTK_STOCK_CUT,          NULL,           command_cut,     NULL, NULL},
+{"copy",    GTK_STOCK_COPY,         NULL,           command_copy,    NULL, NULL},
+{"paste",   GTK_STOCK_PASTE,        NULL,           command_paste,   NULL, NULL},
+{"delete",  GTK_STOCK_DELETE,       NULL,           command_delete,  NULL, NULL},
+{"sep2",    NULL,                   NULL,           NULL,            NULL, NULL},
+{"root",    N_("Root"),             tb_root_xpm,    command_root,    NULL, NULL},
+{"refresh", GTK_STOCK_REFRESH,      NULL,           command_refresh, NULL, NULL},
+{"add",     GTK_STOCK_ADD,          NULL,           command_add,     NULL, NULL},
+#if GTK_CHECK_VERSION(2,6,0)
+{"edit",    GTK_STOCK_EDIT,         NULL,           command_edit,    NULL, NULL},
+#else /* not GTK_CHECK_VERSION(2,6,0) */
+{"edit",    N_("Edit"),             tb_edit_xpm,    command_edit,    NULL, NULL},
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
+{"search",  N_("Search Directory"), tb_search_xpm,  command_search,  NULL, NULL},
+{"sep2",    NULL,                   NULL,           NULL,            NULL, NULL},
+{"up",      GTK_STOCK_GO_UP,        NULL,           command_up,      NULL, NULL},
+{"down",    GTK_STOCK_GO_DOWN,      NULL,           command_down,    NULL, NULL},
+{NULL,      NULL,                   NULL,           NULL,            NULL, NULL}};
 
 
 /******************************************************************************
@@ -150,8 +188,10 @@ main (int   argc,
   GObject *accel, *winmenu;
   GtkAccelGroup *accel_group;
   GtkWidget *handle, *vbox;
-  /* Drag&Drop */
+  /* en:Drag&Drop */
   GtkTargetEntry drag_types[1] = {{"text/uri-list", 0, 0}};
+  /* ja:提供可能なセレクション */
+  GtkTargetEntry targets[1] = {{"Melody maid ID3 Tag", 0, TARGET_MMAID}};
 
   /* 初期化 */
   setlocale (LC_ALL, "");
@@ -406,6 +446,16 @@ MMAID_COPYRIGHT_NOTICE"\n"
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (window), "Melody maid");
   gtk_window_set_default_size (GTK_WINDOW (window), def_width, def_height);
+  glist = g_list_append (NULL, gdk_pixbuf_new_from_xpm_data (mmaid16_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (mmaid24_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (mmaid32_xpm));
+  glist = g_list_append (glist, gdk_pixbuf_new_from_xpm_data (mmaid48_xpm));
+  gtk_window_set_icon_list (GTK_WINDOW (window), glist);
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 0)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 1)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 2)));
+  g_object_unref (G_OBJECT (g_list_nth_data (glist, 3)));
+  g_list_free (glist);
   g_signal_connect (G_OBJECT (window), "delete-event",
                                             G_CALLBACK (signal_delete), NULL);
   g_signal_connect (G_OBJECT (window), "destroy",
@@ -426,7 +476,7 @@ MMAID_COPYRIGHT_NOTICE"\n"
   atom_targets = gdk_atom_intern ("TARGETS", FALSE);
   atom_id3tag = gdk_atom_intern ("Melody maid ID3 Tag", FALSE);
   gtk_selection_add_targets (window, GDK_SELECTION_CLIPBOARD,
-            targets_mmaid, sizeof (targets_mmaid) / sizeof (GtkTargetEntry));
+                                            targets, G_N_ELEMENTS (targets));
   g_signal_connect (G_OBJECT (window), "selection-clear-event",
                                 G_CALLBACK (signal_selection_clear), NULL);
   g_signal_connect (G_OBJECT(window), "selection-get",
@@ -496,7 +546,6 @@ MMAID_COPYRIGHT_NOTICE"\n"
 
   /* ja:表示 */
   gtk_widget_show_all (window);
-  gtk_window_set_policy (GTK_WINDOW (window), TRUE, TRUE, TRUE);
 
   /* ja:新規ウインドウ */
   count = 0;
