@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "process.h"
 
 
@@ -49,18 +48,6 @@ process_dialog_changed (GtkWidget *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-process_dialog_key_press (GtkWidget   *widget,
-                          GdkEventKey *event,
-                          gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 /*  ja:子プロセス起動ダイアログ表示                                         */
 void
 process_dialog (void)
@@ -72,11 +59,11 @@ process_dialog (void)
                             (_("Process"),
                             GTK_WINDOW (window),
                             GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                            GTK_STOCK_OK, GTK_RESPONSE_OK,
                             NULL);
-  g_signal_connect_after (G_OBJECT(dialog), "key-press-event",
-                                G_CALLBACK (process_dialog_key_press), NULL);
+  g_signal_connect (G_OBJECT(dialog), "key-press-event",
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   g_object_set_data (G_OBJECT (dialog), "user_data", GINT_TO_POINTER (FALSE));
   /* ja:エントリー */
   entry0 = gtk_entry_new_with_max_length (256);
