@@ -1,6 +1,6 @@
 /*
     Melody maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,14 +16,12 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include <gdk/gdkkeysyms.h>
 #include "command.h"
 #include "file.h"
 #include "general.h"
 #include "mm_list.h"
 #include "sigmain.h"
 #include "misc/argument.h"
-#include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 
